package de.hft.stuttgart.quality.adapter.types;

import javax.xml.namespace.QName;

import org.xmlobjects.annotation.XMLElement;
import org.xmlobjects.builder.ObjectBuildException;
import org.xmlobjects.builder.ObjectBuilder;
import org.xmlobjects.gml.adapter.geometry.DirectPositionAdapter;
import org.xmlobjects.serializer.ObjectSerializeException;
import org.xmlobjects.serializer.ObjectSerializer;
import org.xmlobjects.stream.XMLReadException;
import org.xmlobjects.stream.XMLReader;
import org.xmlobjects.stream.XMLWriteException;
import org.xmlobjects.stream.XMLWriter;
import org.xmlobjects.xml.Attributes;
import org.xmlobjects.xml.Element;
import org.xmlobjects.xml.Namespaces;

import de.hft.stuttgart.quality.QualityADEModule;
import de.hft.stuttgart.quality.model.types.Edge;

@XMLElement(name = "Edge", namespaceURI = QualityADEModule.NAMESPACE_URI)
public class EdgeAdapter implements ObjectBuilder<Edge>, ObjectSerializer<Edge> {

    @Override
    public Edge createObject(QName name, Object parent) throws ObjectBuildException {
        return new Edge();
    }

    @Override
    public void buildChildObject(Edge object, QName name, Attributes attributes, XMLReader reader) throws ObjectBuildException, XMLReadException {
        if (!QualityADEModule.NAMESPACE_URI.equals(name.getNamespaceURI())) {
            return;
        }
        switch (name.getLocalPart()) {
            case "from" -> object.setFrom(reader.getObjectUsingBuilder(DirectPositionAdapter.class));
            case "to" -> object.setTo(reader.getObjectUsingBuilder(DirectPositionAdapter.class));
        default -> throw new IllegalStateException("Cannot handle name " + name + " when building Edge element");
        }
    }
    
    @Override
    public Element createElement(Edge object, Namespaces namespaces) throws ObjectSerializeException {
    	return Element.of(QualityADEModule.NAMESPACE_URI, "Edge");
    }

    @Override
    public void writeChildElements(Edge object, Namespaces namespaces, XMLWriter writer) throws ObjectSerializeException, XMLWriteException {
        if (object.getFrom() != null) {
            writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "from"), object.getFrom(), DirectPositionAdapter.class, namespaces);
        }
        if (object.getTo() != null) {
            writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "to"), object.getTo(), DirectPositionAdapter.class, namespaces);
        }
    }
}
