package de.hft.stuttgart.quality.adapter.types;

import javax.xml.namespace.QName;

import org.xmlobjects.annotation.XMLElement;
import org.xmlobjects.builder.ObjectBuildException;
import org.xmlobjects.builder.ObjectBuilder;
import org.xmlobjects.serializer.ObjectSerializeException;
import org.xmlobjects.serializer.ObjectSerializer;
import org.xmlobjects.stream.XMLReadException;
import org.xmlobjects.stream.XMLReader;
import org.xmlobjects.stream.XMLWriteException;
import org.xmlobjects.stream.XMLWriter;
import org.xmlobjects.xml.Attributes;
import org.xmlobjects.xml.Element;
import org.xmlobjects.xml.Namespaces;

import de.hft.stuttgart.quality.QualityADEModule;
import de.hft.stuttgart.quality.model.enums.ErrorId;
import de.hft.stuttgart.quality.model.types.Error;

@XMLElement(name = "Error", namespaceURI = QualityADEModule.NAMESPACE_URI)
public class ErrorAdapter implements ObjectBuilder<Error>, ObjectSerializer<Error> {

	@Override
	public Error createObject(QName name, Object parent) throws ObjectBuildException {
		return new Error();
	}

	@Override
	public void buildChildObject(Error object, QName name, Attributes attributes, XMLReader reader)
			throws ObjectBuildException, XMLReadException {
		if (!QualityADEModule.NAMESPACE_URI.equals(name.getNamespaceURI())) {
			return;
		}
		switch (name.getLocalPart()) {
		case "occurrences" -> reader.getTextContent().ifPresent(s -> object.setOccurrences(Integer.parseInt(s)));
		case "name" -> reader.getTextContent().ifPresent(s -> object.setName(ErrorId.valueOf(s)));
		default -> throw new IllegalStateException("Cannot handle name " + name + " when building Error element");
		}
	}
	
	@Override
	public Element createElement(Error object, Namespaces namespaces) throws ObjectSerializeException {
		return Element.of(QualityADEModule.NAMESPACE_URI, "Error");
	}

	@Override
	public void writeChildElements(Error object, Namespaces namespaces, XMLWriter writer)
			throws ObjectSerializeException, XMLWriteException {
		writer.writeElement(Element.of(QualityADEModule.NAMESPACE_URI, "occurrences")
				.addTextContent(Integer.toString(object.getOccurrences())));
		if (object.getName() != null) {
			writer.writeElement(
					Element.of(QualityADEModule.NAMESPACE_URI, "name").addTextContent(object.getName().toString()));
		}
	}
}
