package de.hft.stuttgart.quality.adapter.types;

import javax.xml.namespace.QName;

import org.xmlobjects.annotation.XMLElement;
import org.xmlobjects.builder.ObjectBuildException;
import org.xmlobjects.serializer.ObjectSerializeException;
import org.xmlobjects.stream.XMLReadException;
import org.xmlobjects.stream.XMLReader;
import org.xmlobjects.stream.XMLWriteException;
import org.xmlobjects.stream.XMLWriter;
import org.xmlobjects.xml.Attributes;
import org.xmlobjects.xml.Element;
import org.xmlobjects.xml.Namespaces;

import de.hft.stuttgart.quality.QualityADEModule;
import de.hft.stuttgart.quality.model.types.IntersectingRingsError;

@XMLElement(name = "GE_P_INTERSECTING_RINGS", namespaceURI = QualityADEModule.NAMESPACE_URI)
public class IntersectingRingsErrorAdapter extends AbstractPolygonErrorAdapter<IntersectingRingsError> {

	@Override
	public IntersectingRingsError createObject(QName name, Object parent) throws ObjectBuildException {
		return new IntersectingRingsError();
	}

	@Override
	public void buildChildObject(IntersectingRingsError object, QName name, Attributes attributes, XMLReader reader)
			throws ObjectBuildException, XMLReadException {
		if (!QualityADEModule.NAMESPACE_URI.equals(name.getNamespaceURI())) {
			return;
		}
		switch (name.getLocalPart()) {
		case "linearRingId1" -> reader.getTextContent().ifPresent(object::setLinearRingId1);
		case "linearRingId2" -> reader.getTextContent().ifPresent(object::setLinearRingId2);
		default -> super.buildChildObject(object, name, attributes, reader);
		}
	}
	
	@Override
	public Element createElement(IntersectingRingsError object, Namespaces namespaces) throws ObjectSerializeException {
		return Element.of(QualityADEModule.NAMESPACE_URI, "GE_P_INTERSECTING_RINGS");
	}

	@Override
	public void writeChildElements(IntersectingRingsError object, Namespaces namespaces, XMLWriter writer)
			throws ObjectSerializeException, XMLWriteException {
		super.writeChildElements(object, namespaces, writer);
		
		if (object.getLinearRingId1() != null) {
			writer.writeElement(Element.of(QualityADEModule.NAMESPACE_URI, "linearRingId1")
					.addTextContent(object.getLinearRingId1()));
		}
		if (object.getLinearRingId2() != null) {
			writer.writeElement(Element.of(QualityADEModule.NAMESPACE_URI, "linearRingId2")
					.addTextContent(object.getLinearRingId2()));
		}
	}
}
