package de.hft.stuttgart.quality.adapter.types;

import de.hft.stuttgart.quality.model.enums.RequirementId;
import de.hft.stuttgart.quality.model.properties.ParameterProperty;
import de.hft.stuttgart.quality.model.types.Requirement;

import de.hft.stuttgart.quality.QualityADEModule;
import de.hft.stuttgart.quality.adapter.properties.ParameterPropertyAdapter;

import org.xmlobjects.annotation.XMLElement;
import org.xmlobjects.builder.ObjectBuildException;
import org.xmlobjects.builder.ObjectBuilder;
import org.xmlobjects.serializer.ObjectSerializeException;
import org.xmlobjects.serializer.ObjectSerializer;
import org.xmlobjects.stream.XMLReadException;
import org.xmlobjects.stream.XMLReader;
import org.xmlobjects.stream.XMLWriteException;
import org.xmlobjects.stream.XMLWriter;
import org.xmlobjects.xml.Attributes;
import org.xmlobjects.xml.Element;
import org.xmlobjects.xml.Namespaces;

import javax.xml.namespace.QName;

@XMLElement(name = "Requirement", namespaceURI = QualityADEModule.NAMESPACE_URI)
public class RequirementAdapter implements ObjectBuilder<Requirement>, ObjectSerializer<Requirement> {

	@Override
	public Requirement createObject(QName name, Object parent) throws ObjectBuildException {
		return new Requirement();
	}

	@Override
	public void buildChildObject(Requirement object, QName name, Attributes attributes, XMLReader reader)
			throws ObjectBuildException, XMLReadException {
		if (!QualityADEModule.NAMESPACE_URI.equals(name.getNamespaceURI())) {
			return;
		}
		switch (name.getLocalPart()) {
		case "enabled" -> reader.getTextContent().ifPresent(s -> object.setEnabled(Boolean.parseBoolean(s)));
		case "requirementType" -> object.setRequirementType(RequirementId.valueOf(reader.getTextContent().get()));
		case "parameter" -> object.getParameters().add(reader.getObjectUsingBuilder(ParameterPropertyAdapter.class));
		default -> throw new IllegalStateException("Cannot handle name " + name + " when building Requirement element");
		}
	}

	@Override
	public Element createElement(Requirement object, Namespaces namespaces) throws ObjectSerializeException {
		return Element.of(QualityADEModule.NAMESPACE_URI, "Requirement");
	}

	@Override
	public void writeChildElements(Requirement object, Namespaces namespaces, XMLWriter writer)
			throws ObjectSerializeException, XMLWriteException {
		writer.writeElement(Element.of(QualityADEModule.NAMESPACE_URI, "enabled")
				.addTextContent(Boolean.toString(object.isEnabled())));
		if (object.getRequirementType() != null) {
			writer.writeElement(Element.of(QualityADEModule.NAMESPACE_URI, "requirementType")
					.addTextContent(object.getRequirementType().toString()));
		}
		for (ParameterProperty params : object.getParameters()) {
			writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "parameter"), params,
					ParameterPropertyAdapter.class, namespaces);
		}
	}
}
