package de.hft.stuttgart.quality.adapter.types;

import javax.xml.namespace.QName;

import org.xmlobjects.annotation.XMLElement;
import org.xmlobjects.builder.ObjectBuildException;
import org.xmlobjects.gml.adapter.geometry.DirectPositionAdapter;
import org.xmlobjects.serializer.ObjectSerializeException;
import org.xmlobjects.stream.XMLReadException;
import org.xmlobjects.stream.XMLReader;
import org.xmlobjects.stream.XMLWriteException;
import org.xmlobjects.stream.XMLWriter;
import org.xmlobjects.xml.Attributes;
import org.xmlobjects.xml.Element;
import org.xmlobjects.xml.Namespaces;

import de.hft.stuttgart.quality.QualityADEModule;
import de.hft.stuttgart.quality.adapter.properties.EdgePropertyAdapter;
import de.hft.stuttgart.quality.model.enums.RingSelfIntType;
import de.hft.stuttgart.quality.model.types.RingSelfIntersectionError;

@XMLElement(name = "GE_R_SELF_INTERSECTION", namespaceURI = QualityADEModule.NAMESPACE_URI)
public class RingSelfIntersectionErrorAdapter extends AbstractRingErrorAdapter<RingSelfIntersectionError> {

	@Override
	public RingSelfIntersectionError createObject(QName name, Object parent) throws ObjectBuildException {
		return new RingSelfIntersectionError();
	}

	@Override
	public void buildChildObject(RingSelfIntersectionError object, QName name, Attributes attributes, XMLReader reader)
			throws ObjectBuildException, XMLReadException {
		if (!QualityADEModule.NAMESPACE_URI.equals(name.getNamespaceURI())) {
			return;
		}
		switch (name.getLocalPart()) {
		case "type" -> reader.getTextContent().ifPresent(s -> object.setType(RingSelfIntType.valueOf(s)));
		case "edge1" -> object.setEdge1(reader.getObjectUsingBuilder(EdgePropertyAdapter.class));
		case "edge2" -> object.setEdge2(reader.getObjectUsingBuilder(EdgePropertyAdapter.class));
		case "vertex1" -> object.setVertex1(reader.getObjectUsingBuilder(DirectPositionAdapter.class));
		case "vertex2" -> object.setVertex2(reader.getObjectUsingBuilder(DirectPositionAdapter.class));
		default -> super.buildChildObject(object, name, attributes, reader);
		}
	}

	@Override
	public Element createElement(RingSelfIntersectionError object, Namespaces namespaces)
			throws ObjectSerializeException {
		return Element.of(QualityADEModule.NAMESPACE_URI, "GE_R_SELF_INTERSECTION");
	}

	@Override
	public void writeChildElements(RingSelfIntersectionError object, Namespaces namespaces, XMLWriter writer)
			throws ObjectSerializeException, XMLWriteException {
		super.writeChildElements(object, namespaces, writer);
		if (object.getEdge1() != null) {
			writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "edge1"), object.getEdge1(),
					EdgePropertyAdapter.class, namespaces);
		}
		if (object.getEdge2() != null) {
			writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "edge2"), object.getEdge2(),
					EdgePropertyAdapter.class, namespaces);
		}
		if (object.getVertex1() != null) {
			writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "vertex1"),
					object.getVertex1(), DirectPositionAdapter.class, namespaces);
		}
		if (object.getVertex2() != null) {
			writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "vertex2"),
					object.getVertex2(), DirectPositionAdapter.class, namespaces);
		}
		if (object.getType() != null) {
			writer.writeElement(
					Element.of(QualityADEModule.NAMESPACE_URI, "type").addTextContent(object.getType().toString()));
		}
	}
}
