package de.hft.stuttgart.quality.adapter.types;

import javax.xml.namespace.QName;

import org.xmlobjects.annotation.XMLElement;
import org.xmlobjects.builder.ObjectBuildException;
import org.xmlobjects.serializer.ObjectSerializeException;
import org.xmlobjects.stream.XMLReadException;
import org.xmlobjects.stream.XMLReader;
import org.xmlobjects.stream.XMLWriteException;
import org.xmlobjects.stream.XMLWriter;
import org.xmlobjects.xml.Attributes;
import org.xmlobjects.xml.Element;
import org.xmlobjects.xml.Namespaces;

import de.hft.stuttgart.quality.QualityADEModule;
import de.hft.stuttgart.quality.model.types.SemanticAttributeMissingError;

@XMLElement(name = "SE_ATTRIBUTE_MISSING", namespaceURI = QualityADEModule.NAMESPACE_URI)
public class SemanticAttributeMissingErrorAdapter extends AbstractSemanticErrorAdapter<SemanticAttributeMissingError> {

	@Override
	public SemanticAttributeMissingError createObject(QName name, Object parent) throws ObjectBuildException {
		return new SemanticAttributeMissingError();
	}

	@Override
	public void buildChildObject(SemanticAttributeMissingError object, QName name, Attributes attributes,
			XMLReader reader) throws ObjectBuildException, XMLReadException {
		if (!QualityADEModule.NAMESPACE_URI.equals(name.getNamespaceURI())) {
			return;
		}
		switch (name.getLocalPart()) {
		case "childId" -> reader.getTextContent().ifPresent(object::setChildId);
		case "attributeName" -> reader.getTextContent().ifPresent(object::setAttributeName);
		case "generic" -> reader.getTextContent().ifPresent(s -> object.setGeneric(Boolean.parseBoolean(s)));
		default -> throw new IllegalStateException(
				"Cannot handle name " + name + " when building SemanticAttributeMissingError element");
		}
	}
	
	@Override
	public Element createElement(SemanticAttributeMissingError object, Namespaces namespaces)
			throws ObjectSerializeException {
		return Element.of(QualityADEModule.NAMESPACE_URI, "SE_ATTRIBUTE_MISSING");
	}

	@Override
	public void writeChildElements(SemanticAttributeMissingError object, Namespaces namespaces, XMLWriter writer)
			throws ObjectSerializeException, XMLWriteException {
		if (object.getChildId() != null) {
			writer.writeElement(
					Element.of(QualityADEModule.NAMESPACE_URI, "childId").addTextContent(object.getChildId()));
		}
		if (object.getAttributeName() != null) {
			writer.writeElement(Element.of(QualityADEModule.NAMESPACE_URI, "attributeName")
					.addTextContent(object.getAttributeName()));
		}
		writer.writeElement(Element.of(QualityADEModule.NAMESPACE_URI, "generic")
				.addTextContent(Boolean.toString(object.isGeneric())));
	}
}
