package de.hft.stuttgart.quality.adapter.types;

import javax.xml.namespace.QName;

import org.xmlobjects.annotation.XMLElement;
import org.xmlobjects.builder.ObjectBuildException;
import org.xmlobjects.serializer.ObjectSerializeException;
import org.xmlobjects.stream.XMLReadException;
import org.xmlobjects.stream.XMLReader;
import org.xmlobjects.stream.XMLWriteException;
import org.xmlobjects.stream.XMLWriter;
import org.xmlobjects.xml.Attributes;
import org.xmlobjects.xml.Element;
import org.xmlobjects.xml.Namespaces;

import de.hft.stuttgart.quality.QualityADEModule;
import de.hft.stuttgart.quality.model.types.SemanticAttributeWrongValueError;

@XMLElement(name = "SE_ATTRIBUTE_WRONG_VALUE", namespaceURI = QualityADEModule.NAMESPACE_URI)
public class SemanticAttributeWrongValueErrorAdapter
		extends AbstractSemanticErrorAdapter<SemanticAttributeWrongValueError> {

	@Override
	public SemanticAttributeWrongValueError createObject(QName name, Object parent) throws ObjectBuildException {
		return new SemanticAttributeWrongValueError();
	}

	@Override
	public void buildChildObject(SemanticAttributeWrongValueError object, QName name, Attributes attributes,
			XMLReader reader) throws ObjectBuildException, XMLReadException {
		if (!QualityADEModule.NAMESPACE_URI.equals(name.getNamespaceURI())) {
			return;
		}
		switch (name.getLocalPart()) {
		case "childId" -> reader.getTextContent().ifPresent(object::setChildId);
		case "attributeName" -> reader.getTextContent().ifPresent(object::setAttributeName);
		case "generic" -> reader.getTextContent().ifPresent(s -> object.setGeneric(Boolean.parseBoolean(s)));
		default -> throw new IllegalStateException(
				"Cannot handle name " + name + " when building SemanticAttributeWrongValueError element");
		}
	}
	
	@Override
	public Element createElement(SemanticAttributeWrongValueError object, Namespaces namespaces)
			throws ObjectSerializeException {
		return Element.of(QualityADEModule.NAMESPACE_URI, "SE_ATTRIBUTE_WRONG_VALUE");
	}

	@Override
	public void writeChildElements(SemanticAttributeWrongValueError object, Namespaces namespaces, XMLWriter writer)
			throws ObjectSerializeException, XMLWriteException {
		super.writeChildElements(object, namespaces, writer);
		if (object.getChildId() != null) {
			writer.writeElement(
					Element.of(QualityADEModule.NAMESPACE_URI, "childId").addTextContent(object.getChildId()));
		}
		if (object.getAttributeName() != null) {
			writer.writeElement(Element.of(QualityADEModule.NAMESPACE_URI, "attributeName")
					.addTextContent(object.getAttributeName()));
		}
		writer.writeElement(Element.of(QualityADEModule.NAMESPACE_URI, "generic")
				.addTextContent(Boolean.toString(object.isGeneric())));
	}
}
