package de.hft.stuttgart.quality.adapter.types;

import javax.xml.namespace.QName;

import org.xmlobjects.annotation.XMLElement;
import org.xmlobjects.builder.ObjectBuildException;
import org.xmlobjects.builder.ObjectBuilder;
import org.xmlobjects.serializer.ObjectSerializeException;
import org.xmlobjects.serializer.ObjectSerializer;
import org.xmlobjects.stream.XMLReadException;
import org.xmlobjects.stream.XMLReader;
import org.xmlobjects.stream.XMLWriteException;
import org.xmlobjects.stream.XMLWriter;
import org.xmlobjects.xml.Attributes;
import org.xmlobjects.xml.Element;
import org.xmlobjects.xml.Namespaces;

import de.hft.stuttgart.quality.QualityADEModule;
import de.hft.stuttgart.quality.adapter.properties.ErrorPropertyAdapter;
import de.hft.stuttgart.quality.adapter.properties.FeatureStatisticsPropertyAdapter;
import de.hft.stuttgart.quality.model.properties.ErrorProperty;
import de.hft.stuttgart.quality.model.types.Statistics;

@XMLElement(name = "Statistics", namespaceURI = QualityADEModule.NAMESPACE_URI)
public class StatisticsAdapter implements ObjectBuilder<Statistics>, ObjectSerializer<Statistics> {

	@Override
	public Statistics createObject(QName name, Object parent) throws ObjectBuildException {
		return new Statistics();
	}

	@Override
	public void buildChildObject(Statistics object, QName name, Attributes attributes, XMLReader reader)
			throws ObjectBuildException, XMLReadException {
		if (!QualityADEModule.NAMESPACE_URI.equals(name.getNamespaceURI())) {
			return;
		}
		switch (name.getLocalPart()) {
		case "numErrorBuildings" -> object
				.setNumErrorBuildings(reader.getObjectUsingBuilder(FeatureStatisticsPropertyAdapter.class));
		case "numErrorVegetation" -> object
				.setNumErrorVegetation(reader.getObjectUsingBuilder(FeatureStatisticsPropertyAdapter.class));
		case "numErrorLandObjects" -> object
				.setNumErrorLandObjects(reader.getObjectUsingBuilder(FeatureStatisticsPropertyAdapter.class));
		case "numErrorBridgeObjects" -> object
				.setNumErrorBridgeObjects(reader.getObjectUsingBuilder(FeatureStatisticsPropertyAdapter.class));
		case "numErrorWaterObjects" -> object
				.setNumErrorWaterObjects(reader.getObjectUsingBuilder(FeatureStatisticsPropertyAdapter.class));
		case "numErrorTransportation" -> object
				.setNumErrorTransportation(reader.getObjectUsingBuilder(FeatureStatisticsPropertyAdapter.class));
		case "error" -> object.getErrors().add(reader.getObjectUsingBuilder(ErrorPropertyAdapter.class));
		default -> throw new IllegalStateException("Cannot handle name " + name + " when building Statistics element");
		}
	}

	@Override
	public Element createElement(Statistics object, Namespaces namespaces) throws ObjectSerializeException {
		return Element.of(QualityADEModule.NAMESPACE_URI, "Statistics");
	}

	@Override
	public void writeChildElements(Statistics object, Namespaces namespaces, XMLWriter writer)
			throws ObjectSerializeException, XMLWriteException {
		if (object.getNumErrorBuildings() != null) {
			writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "numErrorBuildings"),
					object.getNumErrorBuildings(), FeatureStatisticsPropertyAdapter.class, namespaces);
		}
		if (object.getNumErrorVegetation() != null) {
			writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "numErrorVegetation"),
					object.getNumErrorVegetation(), FeatureStatisticsPropertyAdapter.class, namespaces);
		}
		if (object.getNumErrorLandObjects() != null) {
			writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "numErrorLandObjects"),
					object.getNumErrorLandObjects(), FeatureStatisticsPropertyAdapter.class, namespaces);
		}
		if (object.getNumErrorBridgeObjects() != null) {
			writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "numErrorBridgeObjects"),
					object.getNumErrorBridgeObjects(), FeatureStatisticsPropertyAdapter.class, namespaces);
		}
		if (object.getNumErrorWaterObjects() != null) {
			writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "numErrorWaterObjects"),
					object.getNumErrorWaterObjects(), FeatureStatisticsPropertyAdapter.class, namespaces);
		}
		if (object.getNumErrorTransportation() != null) {
			writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "numErrorTransportation"),
					object.getNumErrorTransportation(), FeatureStatisticsPropertyAdapter.class, namespaces);
		}
		for (ErrorProperty errorProp : object.getErrors()) {
			writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "error"), errorProp,
					ErrorPropertyAdapter.class, namespaces);
		}
	}
}
