package de.hft.stuttgart.quality.adapter.types;

import javax.xml.namespace.QName;

import org.citygml4j.xml.adapter.core.AbstractFeatureAdapter;
import org.xmlobjects.annotation.XMLElement;
import org.xmlobjects.builder.ObjectBuildException;
import org.xmlobjects.serializer.ObjectSerializeException;
import org.xmlobjects.stream.XMLReadException;
import org.xmlobjects.stream.XMLReader;
import org.xmlobjects.stream.XMLWriteException;
import org.xmlobjects.stream.XMLWriter;
import org.xmlobjects.xml.Attributes;
import org.xmlobjects.xml.Element;
import org.xmlobjects.xml.Namespaces;

import de.hft.stuttgart.quality.QualityADEModule;
import de.hft.stuttgart.quality.adapter.properties.StatisticsPropertyAdapter;
import de.hft.stuttgart.quality.adapter.properties.ValidationPlanPropertyAdapter;
import de.hft.stuttgart.quality.model.types.Validation;

@XMLElement(name = "Validation", namespaceURI = QualityADEModule.NAMESPACE_URI)
public class ValidationAdapter extends  AbstractFeatureAdapter<Validation> {

	private static final ZonedDateTimeAdapter DATE_TIME_ADAPTER = new ZonedDateTimeAdapter();

	@Override
	public Validation createObject(QName name, Object parent) throws ObjectBuildException {
		return new Validation();
	}

	@Override
	public void buildChildObject(Validation object, QName name, Attributes attributes, XMLReader reader)
			throws ObjectBuildException, XMLReadException {
		if (!QualityADEModule.NAMESPACE_URI.equals(name.getNamespaceURI())) {
			return;
		}
		switch (name.getLocalPart()) {
		case "validationDate" -> reader.getTextContent()
				.ifPresent(s -> object.setValidationDate(DATE_TIME_ADAPTER.fromString(s)));
		case "validationSoftware" -> reader.getTextContent().ifPresent(object::setValidationSoftware);
		case "statistics" -> object.setStatistics(reader.getObjectUsingBuilder(StatisticsPropertyAdapter.class));
		case "validationPlan" -> object
				.setValidationPlan(reader.getObjectUsingBuilder(ValidationPlanPropertyAdapter.class));
		default -> super.buildChildObject(object, name, attributes, reader);
		}
	}
	
	@Override
	public Element createElement(Validation object, Namespaces namespaces) throws ObjectSerializeException {
		return Element.of(QualityADEModule.NAMESPACE_URI, "Validation");
	}

	@Override
	public void writeChildElements(Validation object, Namespaces namespaces, XMLWriter writer)
			throws ObjectSerializeException, XMLWriteException {
		super.writeChildElements(object, namespaces, writer);
		if (object.getValidationDate() != null) {
			writer.writeElement(Element.of(QualityADEModule.NAMESPACE_URI, "validationDate")
					.addTextContent(DATE_TIME_ADAPTER.toString(object.getValidationDate())));
		}
		if (object.getValidationSoftware() != null) {
			writer.writeElement(Element.of(QualityADEModule.NAMESPACE_URI, "validationSoftware")
					.addTextContent(object.getValidationSoftware()));
		}
		if (object.getStatistics() != null) {
			writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "statistics"),
					object.getStatistics(), StatisticsPropertyAdapter.class, namespaces);
		}
		if (object.getValidationPlan() != null) {
			writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "validationPlan"),
					object.getValidationPlan(), ValidationPlanPropertyAdapter.class, namespaces);
		}
	}
}
