package de.hft.stuttgart.quality.adapter.types;

import javax.xml.namespace.QName;

import org.xmlobjects.annotation.XMLElement;
import org.xmlobjects.builder.ObjectBuildException;
import org.xmlobjects.builder.ObjectBuilder;
import org.xmlobjects.gml.adapter.base.ReferenceAdapter;
import org.xmlobjects.serializer.ObjectSerializeException;
import org.xmlobjects.serializer.ObjectSerializer;
import org.xmlobjects.stream.XMLReadException;
import org.xmlobjects.stream.XMLReader;
import org.xmlobjects.stream.XMLWriteException;
import org.xmlobjects.stream.XMLWriter;
import org.xmlobjects.xml.Attributes;
import org.xmlobjects.xml.Element;
import org.xmlobjects.xml.Namespaces;

import de.hft.stuttgart.quality.QualityADEModule;
import de.hft.stuttgart.quality.adapter.properties.AbstractErrorPropertyAdapter;
import de.hft.stuttgart.quality.model.enums.ResultType;
import de.hft.stuttgart.quality.model.properties.AbstractErrorProperty;
import de.hft.stuttgart.quality.model.types.ValidationResult;

@XMLElement(name = "ValidationResult", namespaceURI = QualityADEModule.NAMESPACE_URI)
public class ValidationResultAdapter implements ObjectBuilder<ValidationResult>, ObjectSerializer<ValidationResult> {

	@Override
	public ValidationResult createObject(QName name, Object parent) throws ObjectBuildException {
		return new ValidationResult();
	}

	@Override
	public void buildChildObject(ValidationResult object, QName name, Attributes attributes, XMLReader reader)
			throws ObjectBuildException, XMLReadException {
		if (!QualityADEModule.NAMESPACE_URI.equals(name.getNamespaceURI())) {
			return;
		}
		switch (name.getLocalPart()) {
		case "validationPlanID" -> object.setValidationPlanID(reader.getObjectUsingBuilder(ReferenceAdapter.class));
		case "error" -> object.getErrors().add(reader.getObjectUsingBuilder(AbstractErrorPropertyAdapter.class));
		case "resultType" -> reader.getTextContent().ifPresent(s -> object.setResultType(ResultType.valueOf(s)));
		default -> throw new IllegalStateException(
				"Cannot handle name " + name + " when building ValidationResult element");
		}
	}
	
	@Override
	public Element createElement(ValidationResult object, Namespaces namespaces) throws ObjectSerializeException {
		return Element.of(QualityADEModule.NAMESPACE_URI, "ValidationResult");
	}

	@Override
	public void writeChildElements(ValidationResult object, Namespaces namespaces, XMLWriter writer)
			throws ObjectSerializeException, XMLWriteException {
		if (object.getValidationPlanID() != null) {
			writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "validationPlanID"),
					object.getValidationPlanID(), ReferenceAdapter.class, namespaces);
		}
		for (AbstractErrorProperty err : object.getErrors()) {
			writer.writeElementUsingSerializer(Element.of(QualityADEModule.NAMESPACE_URI, "error"), err,
					AbstractErrorPropertyAdapter.class, namespaces);
		}
		if (object.getResultType() != null) {
			writer.writeElement(Element.of(QualityADEModule.NAMESPACE_URI, "resultType")
					.addTextContent(object.getResultType().toString()));
		}
	}
}
