/*-
 * Copyright 2022 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.quality.model.types;

import java.io.Serial;
import java.util.List;

import org.xmlobjects.model.ChildList;

import de.hft.stuttgart.quality.model.properties.PolygonIdListProperty;
import de.hft.stuttgart.quality.model.walker.ValidationErrorVisitor;

public class MultipleComponentsError extends AbstractSolidError {

	@Serial
	private static final long serialVersionUID = 4322219502819024437L;

	private List<PolygonIdListProperty> components;

	public List<PolygonIdListProperty> getComponents() {
		if (components == null) {
			components = new ChildList<>(this);
		}
		return components;
	}
	
	@Override
	public void accept(ValidationErrorVisitor visitor) {
		super.accept(visitor);
		visitor.visit(this);
	}

	public void setComponents(List<PolygonIdListProperty> edges) {
		this.components = asChild(edges);
	}

}
