/*-
 * Copyright 2022 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.quality.model.types;

import java.io.Serial;
import java.util.List;

import org.citygml4j.core.model.ade.ADEObject;
import org.xmlobjects.gml.model.GMLObject;
import org.xmlobjects.model.ChildList;

import de.hft.stuttgart.quality.model.enums.RequirementId;
import de.hft.stuttgart.quality.model.properties.ParameterProperty;

public class Requirement extends GMLObject implements ADEObject {

	@Serial
	private static final long serialVersionUID = 4428291416242684642L;

	private boolean enabled;
	private RequirementId requirementType;
	private List<ParameterProperty> parameters;

	public boolean isEnabled() {
		return enabled;
	}

	public void setEnabled(boolean enabled) {
		this.enabled = enabled;
	}

	public RequirementId getRequirementType() {
		return requirementType;
	}

	public void setRequirementType(RequirementId requirementType) {
		this.requirementType = requirementType;
	}

	public List<ParameterProperty> getParameters() {
		if (parameters == null) {
			parameters = new ChildList<>(this);
		}
		return parameters;
	}

	public void setParameters(List<ParameterProperty> parameters) {
		this.parameters = asChild(parameters);
	}

}
