/*-
 * Copyright 2022 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.quality.model.types;

import java.io.Serial;
import java.util.List;

import org.citygml4j.core.model.ade.ADEObject;
import org.xmlobjects.gml.model.GMLObject;
import org.xmlobjects.model.ChildList;

import de.hft.stuttgart.quality.model.properties.ErrorProperty;
import de.hft.stuttgart.quality.model.properties.FeatureStatisticsProperty;

public class Statistics extends GMLObject implements ADEObject {

    @Serial
    private static final long serialVersionUID = 2935590283116950203L;
    
    private FeatureStatisticsProperty numErrorBuildings;
    private FeatureStatisticsProperty numErrorVegetation;
    private FeatureStatisticsProperty numErrorLandObjects;
    private FeatureStatisticsProperty numErrorBridgeObjects;
    private FeatureStatisticsProperty numErrorWaterObjects;
    private FeatureStatisticsProperty numErrorTransportation;
	private List<ErrorProperty> errors;

	public FeatureStatisticsProperty getNumErrorBuildings() {
		return numErrorBuildings;
	}

	public void setNumErrorBuildings(FeatureStatisticsProperty numErrorBuildings) {
		this.numErrorBuildings = asChild(numErrorBuildings);
	}

	public FeatureStatisticsProperty getNumErrorVegetation() {
		return numErrorVegetation;
	}

	public void setNumErrorVegetation(FeatureStatisticsProperty numErrorVegetation) {
		this.numErrorVegetation = asChild(numErrorVegetation);
	}

	public FeatureStatisticsProperty getNumErrorLandObjects() {
		return numErrorLandObjects;
	}

	public void setNumErrorLandObjects(FeatureStatisticsProperty numErrorLandObjects) {
		this.numErrorLandObjects = asChild(numErrorLandObjects);
	}

	public FeatureStatisticsProperty getNumErrorBridgeObjects() {
		return numErrorBridgeObjects;
	}

	public void setNumErrorBridgeObjects(FeatureStatisticsProperty numErrorBridgeObjects) {
		this.numErrorBridgeObjects = asChild(numErrorBridgeObjects);
	}

	public FeatureStatisticsProperty getNumErrorWaterObjects() {
		return numErrorWaterObjects;
	}

	public void setNumErrorWaterObjects(FeatureStatisticsProperty numErrorWaterObjects) {
		this.numErrorWaterObjects = asChild(numErrorWaterObjects);
	}

	public FeatureStatisticsProperty getNumErrorTransportation() {
		return numErrorTransportation;
	}

	public void setNumErrorTransportation(FeatureStatisticsProperty numErrorTransportation) {
		this.numErrorTransportation = asChild(numErrorTransportation);
	}

	public List<ErrorProperty> getErrors() {
		if (errors == null) {
			errors = new ChildList<>(this);
		}
		return errors;
	}

	public void setErrors(List<ErrorProperty> errors) {
		this.errors = asChild(errors);
	}

}
