/*-
 * Copyright 2022 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.quality.model.types;

import java.io.Serial;
import java.util.List;

import org.citygml4j.core.model.ade.ADEObject;
import org.xmlobjects.gml.model.GMLObject;
import org.xmlobjects.model.ChildList;

import de.hft.stuttgart.quality.model.properties.FilterProperty;
import de.hft.stuttgart.quality.model.properties.GlobalParametersProperty;
import de.hft.stuttgart.quality.model.properties.RequirementProperty;

public class ValidationPlan extends GMLObject implements ADEObject {

	@Serial
	private static final long serialVersionUID = 434443226848485642L;

	private GlobalParametersProperty globalParameters;
	private FilterProperty filter;
	private List<RequirementProperty> requirement;

	public GlobalParametersProperty getGlobalParameters() {
		return globalParameters;
	}

	public void setGlobalParameters(GlobalParametersProperty globalParameters) {
		this.globalParameters = asChild(globalParameters);
	}

	public FilterProperty getFilter() {
		return filter;
	}

	public void setFilter(FilterProperty filter) {
		this.filter = asChild(filter);
	}

	public List<RequirementProperty> getRequirements() {
		if (requirement == null) {
			requirement = new ChildList<>(this);
		}
		return requirement;
	}

	public void setRequirements(List<RequirementProperty> requirement) {
		this.requirement = asChild(requirement);
	}


}
