/*-
 * Copyright 2022 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.quality.model.types;

import java.io.Serial;
import java.util.List;

import org.citygml4j.core.model.ade.ADEObject;
import org.xmlobjects.gml.model.GMLObject;
import org.xmlobjects.gml.model.base.Reference;
import org.xmlobjects.model.ChildList;

import de.hft.stuttgart.quality.model.enums.ResultType;
import de.hft.stuttgart.quality.model.properties.AbstractErrorProperty;
import de.hft.stuttgart.quality.model.walker.ValidationErrorVisitor;

public class ValidationResult extends GMLObject implements ADEObject {

	@Serial
	private static final long serialVersionUID = 4867627296196445082L;

	private Reference validationPlanID;
	private List<AbstractErrorProperty> errors;
	private ResultType resultType;

	public Reference getValidationPlanID() {
		return validationPlanID;
	}

	public void setValidationPlanID(Reference validationPlanID) {
		this.validationPlanID = asChild(validationPlanID);
	}

	public List<AbstractErrorProperty> getErrors() {
		if (errors == null) {
			errors = new ChildList<>(this);
		}
		return errors;
	}

	public void setErrors(List<AbstractErrorProperty> errors) {
		this.errors = errors;
	}

	public ResultType getResultType() {
		return resultType;
	}

	public void setResultType(ResultType resultType) {
		this.resultType = resultType;
	}
	
	public void accept(ValidationErrorVisitor visitor) {
		for (AbstractErrorProperty errorProp : errors) {
			if (errorProp.getObject() == null) {
				continue;
			}
			errorProp.getObject().accept(visitor);
		}
	}

}
