/*-
 * Copyright 2022 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.quality.model.walker;

import de.hft.stuttgart.quality.model.types.AbstractError;
import de.hft.stuttgart.quality.model.types.AbstractGeometryError;
import de.hft.stuttgart.quality.model.types.AbstractPolygonError;
import de.hft.stuttgart.quality.model.types.AbstractRingError;
import de.hft.stuttgart.quality.model.types.AbstractSemanticError;
import de.hft.stuttgart.quality.model.types.AbstractSolidError;
import de.hft.stuttgart.quality.model.types.AllPolygonsOrientedWrongError;
import de.hft.stuttgart.quality.model.types.ConsecutivePointsSameError;
import de.hft.stuttgart.quality.model.types.HoleOutsideError;
import de.hft.stuttgart.quality.model.types.InnerRingsNestedError;
import de.hft.stuttgart.quality.model.types.InteriorDisconnectedError;
import de.hft.stuttgart.quality.model.types.IntersectingRingsError;
import de.hft.stuttgart.quality.model.types.MultipleComponentsError;
import de.hft.stuttgart.quality.model.types.NonManifoldEdgeError;
import de.hft.stuttgart.quality.model.types.NonManifoldVertexError;
import de.hft.stuttgart.quality.model.types.OrientationRingsSameError;
import de.hft.stuttgart.quality.model.types.PlanarDistancePlaneError;
import de.hft.stuttgart.quality.model.types.PlanarNormalsDeviationError;
import de.hft.stuttgart.quality.model.types.PolygonWrongOrientationError;
import de.hft.stuttgart.quality.model.types.RingNotClosedError;
import de.hft.stuttgart.quality.model.types.RingSelfIntersectionError;
import de.hft.stuttgart.quality.model.types.RingTooFewPointsError;
import de.hft.stuttgart.quality.model.types.SemanticAttributeMissingError;
import de.hft.stuttgart.quality.model.types.SemanticAttributeWrongValueError;
import de.hft.stuttgart.quality.model.types.SolidNotClosedError;
import de.hft.stuttgart.quality.model.types.SolidSelfIntersectionError;
import de.hft.stuttgart.quality.model.types.SolidTooFewPolygonsError;

public interface ValidationErrorVisitor {
	
	default void visit(AbstractError err) {
		
	}
	
	default void visit(AbstractGeometryError err) {
		
	}
	
	default void visit(AbstractPolygonError err) {
		
	}
	
	default void visit(AbstractRingError err) {
		
	}
	
	default void visit(AbstractSemanticError err) {
		
	}
	
	default void visit(AbstractSolidError err) {
		
	}
	
	default void visit(AllPolygonsOrientedWrongError err) {
		
	}
	
	default void visit(ConsecutivePointsSameError err) {
		
	}
	
	default void visit(HoleOutsideError err) {
		
	}
	
	default void visit(InnerRingsNestedError err) {
		
	}
	
	default void visit(IntersectingRingsError err) {
		
	}
	
	default void visit(InteriorDisconnectedError err) {
		
	}
	
	default void visit(MultipleComponentsError err) {
		
	}
	
	default void visit(NonManifoldEdgeError err) {
		
	}
	
	default void visit(NonManifoldVertexError err) {
		
	}
	
	default void visit(OrientationRingsSameError err) {
		
	}
	
	default void visit(PlanarDistancePlaneError err) {
		
	}
	
	default void visit(PlanarNormalsDeviationError err) {
		
	}
	
	default void visit(PolygonWrongOrientationError err) {
		
	}
	
	default void visit(RingNotClosedError err) {
		
	}
	
	default void visit(RingSelfIntersectionError err) {
		
	}
	
	default void visit(RingTooFewPointsError err) {
		
	}
	
	default void visit(SemanticAttributeMissingError err) {
		
	}
	
	default void visit(SemanticAttributeWrongValueError err) {
		
	}
	
	default void visit(SolidNotClosedError err) {
		
	}
	
	default void visit(SolidSelfIntersectionError err) {
		
	}
	
	default void visit(SolidTooFewPolygonsError err) {
		
	}
	
}
